@@ -19,17 +19,19 @@ echo "Check sequential file unaligned write (async IO)"
 zonefs_mkfs "$1"
 zonefs_mount "$1"
 
-fio --name=seq_wr --filename="$zonefs_mntdir"/seq/0 \
-    --create_on_open=0 --allow_file_create=0 --unlink=0 \
-    --rw=write --ioengine=libaio --iodepth=8 \
-    --bs=131072 --verify=md5 --do_verify=1 \
-    --continue_on_error=none --direct=1 --offset=4096 && \
+tools/zio --write --fflag=direct --ofst=4096 \
+	--size=135168 --async=8 "$zonefs_mntdir"/seq/0 && \
 	exit_failed " --> SUCCESS (should FAIL)"
 
 sz=$(file_size "$zonefs_mntdir"/seq/0)
 [ "$sz" != "0" ] && \
 	exit_failed " --> Invalid file size $sz B, expected 0 B"
 
+# The file should still be writable
+dd if=/dev/zero of="$zonefs_mntdir"/seq/0 oflag=direct \
+	bs=4096 count=1 conv=notrunc || \
+	exit_failed " --> FAILED (should SUCCEED)"
+
 zonefs_umount
 
 exit 0
