@@ -27,7 +27,7 @@ truncate --no-create --size=0 "$zonefs_mntdir"/seq/0 || \
 
 fio --name=seqwrite --filename="$zonefs_mntdir"/seq/0 \
     --create_on_open=0 --allow_file_create=0 --file_append=1 --unlink=0 \
-    --rw=write --ioengine=psync --iodepth=64 --max-jobs=8 \
+    --rw=write --ioengine=psync --max-jobs=8 \
     --bs=4096 --size="$sz" --verify=md5 --do_verify=1 \
     --continue_on_error=none --direct=1 || \
 	exit_failed "fio write FAILED"
